-- BEGIN COPYRIGHT
-- *******************************************************************
-- Licensed Materials - Property of IBM 
-- 5724-L01, 5655-N53, 5724-I82, 5655-R15
-- (C) Copyright IBM Corporation 2006, 2006. All rights reserved.  
-- US Government Users Restricted Rights - Use, duplication, or 
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- *******************************************************************
-- END COPYRIGHT
--

-- *******************************************
-- Create dynamic artifact repository tables
-- for DB2 on zOS
-- *******************************************

--
-- *******************************************
-- Drop existing tablespaces
-- *******************************************

-- *******************************************
-- Create tablespaces
-- *******************************************
CREATE TABLESPACE BYTESTTS
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 CCSID UNICODE
 SEGSIZE 32
 DEFINE NO
 LOCKSIZE ANY
 BUFFERPOOL @BPTABLE4K@;

CREATE LOB TABLESPACE BBLOB1TS
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL @BPLOB4K@;

CREATE LOB TABLESPACE BBLOB2TS
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL @BPLOB4K@;

CREATE TABLESPACE APTIMETS
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 CCSID UNICODE
  SEGSIZE 32  DEFINE NO
 LOCKSIZE ANY
 BUFFERPOOL @BPTABLE4K@;

-- *******************************************
-- Create table Bytestore and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.BYTESTORE
  (ARTIFACTTNS VARCHAR(250) NOT NULL,
   ARTIFACTNAME VARCHAR(200) NOT NULL,
   ARTIFACTTYPE VARCHAR(50) NOT NULL,
   INITIALBYTES BLOB(30000),
   TIMESTAMP1 DECIMAL(19,0) NOT NULL,
   FILENAME VARCHAR(250),
   BACKINGCLASS VARCHAR(250),
   CHARENCODING VARCHAR(50),
   APPNAME VARCHAR(200),
   COMPONENTTNS VARCHAR(250),
   COMPONENTNAME VARCHAR(200),
   SCAMODULENAME VARCHAR(200),
   SCACOMPONENTNAME VARCHAR(200),
   CONSTRAINT PK_BYTESTORE PRIMARY KEY
    (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME) )
IN @DB_NAME@.BYTESTTS;


CREATE UNIQUE INDEX @SCHEMA@.BSTORE_INDEX_PK 
ON @SCHEMA@.BYTESTORE (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;

CREATE AUX TABLE @SCHEMA@.BYTESTORE_1 IN @DB_NAME@.BBLOB1TS
STORES @SCHEMA@.BYTESTORE COLUMN INITIALBYTES;

CREATE INDEX @SCHEMA@.BYTESTORE_1IDX ON @SCHEMA@.BYTESTORE_1
  USING STOGROUP @STOGRP@
  BUFFERPOOL @BPINDEX@ ;

-- *******************************************
-- Create table Bytestoreoverflow and indexes
-- *******************************************

CREATE TABLE @SCHEMA@.BYTESTOREOVERFLOW
  (ARTIFACTTYPE VARCHAR(50) NOT NULL,
   ARTIFACTTNS VARCHAR(250) NOT NULL,
   ARTIFACTNAME VARCHAR(200) NOT NULL,
   SEQUENCENUMBER INTEGER NOT NULL,
   BYTES BLOB(30000),
   CONSTRAINT PK_BYTESTOREOVERFL PRIMARY KEY
    (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME, SEQUENCENUMBER) )
IN @DB_NAME@.BYTESTTS;

CREATE UNIQUE INDEX @SCHEMA@.BSTOREOVERFLOW_INDEX_PK 
ON @SCHEMA@.BYTESTOREOVERFLOW
    (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME, SEQUENCENUMBER)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;

CREATE AUX TABLE @SCHEMA@.BYTESTOREOVERFLOW_1 IN @DB_NAME@.BBLOB2TS
STORES @SCHEMA@.BYTESTOREOVERFLOW COLUMN BYTES;

CREATE INDEX @SCHEMA@.BYTESTOREOVERFLOW_1IDX
    ON @SCHEMA@.BYTESTOREOVERFLOW_1
 USING STOGROUP @STOGRP@
 BUFFERPOOL @BPINDEX@ ;

-- *******************************************
-- Create table Apptimestamp and indexes
-- *******************************************

CREATE TABLE @SCHEMA@.APPTIMESTAMP
  (APPNAME VARCHAR(200) NOT NULL,
   TIMESTAMP1 DECIMAL(19,0) NOT NULL,
   CONSTRAINT PK_APPTIMESTAMP PRIMARY KEY (APPNAME) )
IN @DB_NAME@.APTIMETS;

CREATE UNIQUE INDEX @SCHEMA@.APPTIMESTAMP_INDEX_PK 
ON @SCHEMA@.APPTIMESTAMP (APPNAME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;

-- *******************************************
-- Create the CUSTPROPERTIES table
-- *******************************************

CREATE TABLE @SCHEMA@.CUSTPROPERTIES
  (PROPERTYID VARCHAR (128) NOT NULL,
   ARTIFACTTNS VARCHAR(250) NOT NULL,
   ARTIFACTNAME VARCHAR(200) NOT NULL,
   ARTIFACTTYPE VARCHAR(50) NOT NULL,
   PNAME VARCHAR(250) NOT NULL,
   PVALUE VARCHAR(250) NOT NULL,
   PTYPE VARCHAR (16) NOT NULL,
   CONSTRAINT PK_CUSTPROPERTIES PRIMARY KEY (PROPERTYID) )
   IN @DB_NAME@.APTIMETS;

CREATE UNIQUE INDEX @SCHEMA@.CUSTPROP0_PK ON @SCHEMA@.CUSTPROPERTIES
    (PROPERTYID) USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;

CREATE INDEX @SCHEMA@.CUSTPROP1_PK ON @SCHEMA@.CUSTPROPERTIES
    (ARTIFACTTYPE, ARTIFACTTNS)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;

CREATE INDEX @SCHEMA@.CUSTPROP2_PK ON @SCHEMA@.CUSTPROPERTIES
    (ARTIFACTTYPE, ARTIFACTNAME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;
      
CREATE INDEX @SCHEMA@.CUSTPROP3_PK ON @SCHEMA@.CUSTPROPERTIES
    (ARTIFACTTYPE, ARTIFACTNAME, ARTIFACTTNS)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;      
  
CREATE INDEX @SCHEMA@.CUSTPROP4_PK ON @SCHEMA@.CUSTPROPERTIES
    (ARTIFACTTYPE, PNAME) USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;        
           
CREATE INDEX @SCHEMA@.CUSTPROP5_PK ON @SCHEMA@.CUSTPROPERTIES
    (ARTIFACTTYPE, ARTIFACTTNS, PNAME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;                   
